@@ -159,7 +159,7 @@ aft_core_info_t aft_core_table[] = {
 	{ AFT_4SERIAL_RS232_SUBSYS_VENDOR, AFT_CHIP_X1000, AFT_HDLC_CORE_ID, 0x01, 0x4F,	
 	  "A140_0100_V", "A140_0100_V*.BIN", AFT_CORE_X1000_SIZE },
 	{ AFT_A600_SUBSYS_VENDOR, AFT_CHIP_X250, AFT_ANALOG_FE_CORE_ID, 0x20, 0x5B,	
-	  "A600_0025_V", "A600_0025_V*.BIN", AFT_CORE_X250_SIZE },
+	  "B600_0025_V", "B600_0025_V*.BIN", AFT_CORE_X250_SIZE },
 
 #if 0
 	{ AFT_TE1_ATM_CORE_ID,	
@@ -341,7 +341,8 @@ static int wan_aftup_gettype(wan_aftup_t *aft, char *type)
 		//strcpy(aft->prefix_fw, "AFT_RM");
 		aft->cpld.adptr_type = AFT_ADPTR_4SERIAL_RS232;
 		aft->cpld.iface	= &aftup_shark_flash_iface;
-	}else if (strncmp(type,"AFT-A600",8) == 0){
+	}else if (strncmp(type,"AFT-A600",8) == 0 ||
+	          strncmp(type,"AFT-B600",8) == 0){
 		aft->cpld.adptr_type = AFT_ADPTR_A600;
 		aft->cpld.iface	= &aftup_a600_flash_iface;
 	}else{
